@@ -8,22 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_cloudwatch._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_stepfunctions._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-fargate-stepfunctions",
-    "1.181.1",
+    "2.8.0",
     __name__[0:-6],
-    "aws-fargate-stepfunctions@1.181.1.jsii.tgz",
+    "aws-fargate-stepfunctions@2.8.0.jsii.tgz",
 )
 
 __all__ = [
